==> common-2.0.0-sources.jar: cn/gtmap/gtc/resource/domain/resource/metadata/Announcement.java <==
package cn.gtmap.gtc.resource.domain.resource.metadata;

import cn.gtmap.gtc.resource.domain.BaseEntity;

import javax.persistence.*;
import java.util.Date;

/**
 * 通知公告
 * Created by Administrator on 2018/3/27.
 */
@Entity
@Table(name = "gt_res_announcement")
public class Announcement extends BaseEntity {
    /**
     * 标题
     */
    @Column(name = "title")
    private String title;
    /**
     * 频道
     */
    @Column(name = "channel")
    private String channel;
    /**
     * 发布者
     */
    @Column(name = "publisher")
    private String publisher;
    /**
     * 发布者账号
     */
    @Column(name = "username")
    private String username;

    @Column(name = "publishAt")
    private Date publishAt;

    /**
     * 等级
     */
    @Column(name = "grade")
    private String grade;
    /**
     * 详细信息
     */
    @Column(name = "content")
    private String content;
    /**
     * 附件Id
     */
    @Column(name = "resId")
    private String resId;

    @Column(name = "top")
    private boolean top;

    @Column(name = "weight")
    private Integer weight;

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getGrade() {
        return grade;
    }

    public void setGrade(String grade) {
        this.grade = grade;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getChannel() {
        return channel;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public String getPublisher() {
        return publisher;
    }

    public void setPublisher(String publisher) {
        this.publisher = publisher;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getResId() {
        return resId;
    }

    public void setResId(String resId) {
        this.resId = resId;
    }

    public Date getPublishAt() {
        return publishAt;
    }

    public void setPublishAt(Date publishAt) {
        this.publishAt = publishAt;
    }

    public Integer getWeight() {
        return weight;
    }

    public void setWeight(Integer weight) {
        this.weight = weight;
    }

    public boolean isTop() {
        return top;
    }

    public void setTop(boolean top) {
        this.top = top;
    }
}

==> common-2.0.2-sources.jar: cn/gtmap/gtc/resource/domain/resource/metadata/Announcement.java <==
package cn.gtmap.gtc.resource.domain.resource.metadata;

import cn.gtmap.gtc.resource.domain.BaseEntity;

import javax.persistence.*;
import java.util.Date;

/**
 * 通知公告
 * Created by Administrator on 2018/3/27.
 * @author gt_weiran
 */
@Entity
@Table(name = "gt_res_announcement")
public class Announcement extends BaseEntity {
    /**
     * 标题
     */
    @Column(name = "title")
    private String title;
    /**
     * 频道
     */
    @Column(name = "channel")
    private String channel;
    /**
     * 发布者
     */
    @Column(name = "publisher")
    private String publisher;
    /**
     * 发布者账号
     */
    @Column(name = "username")
    private String username;

    @Column(name = "publishAt")
    private Date publishAt;

    /**
     * 公告等级
     */
    @Column(name = "grade")
    private String grade;
    /**
     * 详细内容
     */
    @Column(name = "content")
    private String content;
    /**
     * 附件Id
     */
    @Column(name = "resId")
    private String resId;

    /**
     * 是否置顶
     */
    @Column(name = "top")
    private boolean top;

    @Column(name = "weight")
    private Integer weight;

    /**
     * 指定类型
     * @return
     */
    @Column(name = "receivedType", columnDefinition = "varchar(255)")
    private String receivedType;

    /**
     * 公告关系id
     * @return
     */
    @Column(name = "relation", columnDefinition = "varchar(255)")
    private String relation;

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getGrade() {
        return grade;
    }

    public void setGrade(String grade) {
        this.grade = grade;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getChannel() {
        return channel;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public String getPublisher() {
        return publisher;
    }

    public void setPublisher(String publisher) {
        this.publisher = publisher;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getResId() {
        return resId;
    }

    public void setResId(String resId) {
        this.resId = resId;
    }

    public Date getPublishAt() {
        return publishAt;
    }

    public void setPublishAt(Date publishAt) {
        this.publishAt = publishAt;
    }

    public Integer getWeight() {
        return weight;
    }

    public void setWeight(Integer weight) {
        this.weight = weight;
    }

    public boolean isTop() {
        return top;
    }

    public void setTop(boolean top) {
        this.top = top;
    }

    public String getReceivedType() {
        return receivedType;
    }

    public void setReceivedType(String receivedType) {
        this.receivedType = receivedType;
    }

    public String getRelation() {
        return relation;
    }

    public void setRelation(String relation) {
        this.relation = relation;
    }
}
